@@ -72,6 +72,9 @@ class API(object):
 
         response = http_method(url=path, data=data, params=kwargs, headers=headers)
 
+        # closing the http connection after a request
+        http.close()
+
         asset_id = kwargs.get("asset_id", "Unknown") or "Unknown"
 
         if response.status_code == 401:
