@@ -58,7 +58,7 @@ class HoleSection(Element):
 
     def __repr__(self):
         return (
-            f"{nanround(self.inner_diameter, 2)} in, "
+            f"{nanround(self.inner_diameter, 2):>6} in, "
             f"{super().__repr__()}, "
             f"{self.hole_type.value}"
         )
